# -*- Makefile -*-
# ----------------------------------------------
PROG = tracer.exe

SRCS0 = $(wildcard *.f90)
SRCS  = $(filter-out F%.f90, $(SRCS0))

OBJS := $(SRCS:.f90=.o)

MAKEFILE_INC = depend.mk
F_makedepend = ./sfmakedepend --file=$(MAKEFILE_INC)

all: $(PROG)

.PHONY: update
update: messy_main_tracer_pdef_si.f90 messy_main_tracer_family_si.f90 messy_ptrac_si.f90

# update file dependencies
depend $(MAKEFILE_INC): 
	$(F_makedepend) $(SRCS)

install: all
	cp -pf $(srcdir)/$(PROG) $(bindir)/.

clean:
	rm -f $(srcdir)/*.o
	rm -f $(srcdir)/*.mod
	rm -f *.log
	rm -f *~

distclean: clean
	rm -f $(srcdir)/$(PROG)
	rm -f $(bindir)/$(PROG)

.PHONY: run
run: all ptrac.nml-raw
	rm -fr ptrac.nml
	./copynml.sh ptrac.nml-raw ptrac.nml
	$(srcdir)/$(PROG)

.PHONY: zip
zip:
	zip -or messy_tracer_box.zip * -x '*.o' -x '*.mod' -x '*.log' -x '*~' -x '*.old' -x Makefile.m -x '*.zip' -x '*.exe'

.PHONY: list
list:
	@echo '------------------------------------------------------'
	@echo "SRCS = $(SRCS)"
	@echo '------------------------------------------------------'

.PHONY: check
check:
	-forchk -define BOX -rigor -cond -f95 -obs -ff -decl -ext -intr -spec -ancmpl -anprg -anref -shcom -shinc -shmod -shprg -shref -shsrc -shsub -inf -plen 25 -pwid 132 -l fchk_tmp.lst -rep fchk_report.log *.f90 >& forcheck.log
	@echo 'CREATING LOG-FILES ...........................................'
	@rm -f *.log
	@gawk -f ./lst2log.gawk fchk_tmp.lst
	@rm -f fchk_tmp.lst
	@ls -l *.log
	@echo '..............................................................'

$(PROG): update depend $(OBJS)
	$(F90) $(F90FLAGS) $(DEFOPT)BOX -o $@ $(OBJS)

.SUFFIXES: $(SUFFIXES) .f90

%.o: %.f90
	$(F90) $(F90FLAGS) $(DEFOPT)BOX -c $<

# ----------------------------------------------

messy_main_tracer_pdef_si.f90: messy_main_tracer_pdef_e5.f90-raw
	@echo 'creating '$@
	rm -f $@
	sed 's|_e5|_si|g' messy_main_tracer_pdef_e5.f90-raw 1> $@

messy_main_tracer_family_si.f90: messy_main_tracer_family_e5.f90-raw
	@echo 'creating '$@
	rm -f $@
	sed 's|_e5|_si|g' messy_main_tracer_family_e5.f90-raw 1> $@

messy_ptrac_si.f90: messy_ptrac_e5.f90-raw
	@echo 'creating '$@
	rm -f $@
	sed 's|_e5|_si|g' messy_ptrac_e5.f90-raw 1> $@

# ----------------------------------------------

